@@ -63,6 +63,13 @@ Property<PropertyType>::is_writable() const
     return writable;
 }
 
+template<typename PropertyType>
+const core::Signal<void>&
+Property<PropertyType>::about_to_be_destroyed() const
+{
+    return signal_about_to_be_destroyed;
+}
+
 template<typename PropertyType>
 std::shared_ptr<Property<PropertyType>>
 Property<PropertyType>::make_property(const std::shared_ptr<Object>& parent)
@@ -108,6 +115,20 @@ Property<PropertyType>::Property(
     }
 }
 
+template<typename PropertyType>
+Property<PropertyType>::~Property()
+{
+    try
+    {
+        signal_about_to_be_destroyed();
+    } catch(...)
+    {
+        // Consciously dropping all exceptions here.
+        // There is hardly anything we can do about it while
+        // tearing down the object anyway.
+    }
+}
+
 template<typename PropertyType>
 void
 Property<PropertyType>::handle_get(const Message::Ptr& msg)
