@@ -79,7 +79,7 @@ void Service::add_match(const MatchRule& rule)
 
 void Service::remove_match(const MatchRule& rule)
 {
-    connection->remove_match(rule);
+    connection->remove_match(rule.sender(name));
 }
 
 Service::Service(const Bus::Ptr& connection, const std::string& name)
